@@ -54,6 +54,7 @@
 // Bound library includes
 #include <Qt3DRender/qraycaster.h>
 #include <Qt3DRender/qabstractfunctor.h>
+#include <Qt3DRender/qrenderapi.h>
 #include <Qt3DRender/qdepthtest.h>
 #include <Qt3DRender/qrendertargetselector.h>
 #include <Qt3DRender/qdithering.h>
@@ -149,8 +150,8 @@
 #include <Qt3DRender/qclearbuffers.h>
 #include <Qt3DRender/qscissortest.h>
 #include <Qt3DRender/qmaterial.h>
-#include <Qt3DRender/qrendercapabilities.h>
 #include <Qt3DRender/qlayer.h>
+#include <Qt3DRender/qrendercapabilities.h>
 #include <Qt3DRender/qcameralens.h>
 #include <Qt3DRender/qgraphicsapifilter.h>
 #include <Qt3DRender/qbufferdatagenerator.h>
@@ -175,188 +176,190 @@
 
 // Type indices
 enum : int {
+    SBK_QT3DRENDER_API_IDX                                   = 3,
     SBK_Qt3DRenderQT3DRENDER_IDX                             = 2,
-    SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX               = 3,
-    SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX                      = 4,
-    SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                        = 5,
-    SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                   = 6,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                    = 7,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX            = 9,
-    SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX         = 8,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                      = 10,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 16,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 17,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 18,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX               = 14,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX          = 13,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX   = 11,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX       = 12,
-    SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX           = 15,
-    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 19,
-    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 20,
-    SBK_QT3DRENDER_QALPHATEST_IDX                            = 21,
-    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 22,
-    SBK_QT3DRENDER_QATTRIBUTE_IDX                            = 23,
-    SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX              = 24,
-    SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX             = 25,
-    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 26,
-    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 27,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 28,
-    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 29,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 30,
-    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 31,
-    SBK_QT3DRENDER_QBUFFER_IDX                               = 32,
-    SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                    = 34,
-    SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                     = 35,
-    SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                    = 33,
-    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 36,
-    SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                  = 37,
-    SBK_QT3DRENDER_QCAMERA_IDX                               = 38,
-    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 39,
-    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 40,
-    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 41,
-    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 42,
-    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 43,
-    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 44,
+    SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX               = 4,
+    SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX                      = 5,
+    SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX                   = 7,
+    SBK_QT3DRENDER_QABSTRACTLIGHT_IDX                        = 6,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_RUNMODE_IDX            = 10,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_FILTERMODE_IDX         = 9,
+    SBK_QT3DRENDER_QABSTRACTRAYCASTER_IDX                    = 8,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_STATUS_IDX               = 17,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TARGET_IDX               = 18,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_TEXTUREFORMAT_IDX        = 19,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_FILTER_IDX               = 15,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_CUBEMAPFACE_IDX          = 14,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONFUNCTION_IDX   = 12,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_COMPARISONMODE_IDX       = 13,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_HANDLETYPE_IDX           = 16,
+    SBK_QT3DRENDER_QABSTRACTTEXTURE_IDX                      = 11,
+    SBK_QT3DRENDER_QABSTRACTTEXTUREIMAGE_IDX                 = 20,
+    SBK_QT3DRENDER_QALPHACOVERAGE_IDX                        = 21,
+    SBK_QT3DRENDER_QALPHATEST_ALPHAFUNCTION_IDX              = 23,
+    SBK_QT3DRENDER_QALPHATEST_IDX                            = 22,
+    SBK_QT3DRENDER_QATTRIBUTE_ATTRIBUTETYPE_IDX              = 25,
+    SBK_QT3DRENDER_QATTRIBUTE_VERTEXBASETYPE_IDX             = 26,
+    SBK_QT3DRENDER_QATTRIBUTE_IDX                            = 24,
+    SBK_QT3DRENDER_QBLENDEQUATION_BLENDFUNCTION_IDX          = 28,
+    SBK_QT3DRENDER_QBLENDEQUATION_IDX                        = 27,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_BLENDING_IDX      = 30,
+    SBK_QT3DRENDER_QBLENDEQUATIONARGUMENTS_IDX               = 29,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_INTERPOLATIONMETHOD_IDX  = 32,
+    SBK_QT3DRENDER_QBLITFRAMEBUFFER_IDX                      = 31,
+    SBK_QT3DRENDER_QBUFFER_BUFFERTYPE_IDX                    = 35,
+    SBK_QT3DRENDER_QBUFFER_USAGETYPE_IDX                     = 36,
+    SBK_QT3DRENDER_QBUFFER_ACCESSTYPE_IDX                    = 34,
+    SBK_QT3DRENDER_QBUFFER_IDX                               = 33,
+    SBK_QT3DRENDER_QBUFFERCAPTURE_IDX                        = 37,
+    SBK_QT3DRENDER_QBUFFERDATAGENERATOR_IDX                  = 38,
+    SBK_QT3DRENDER_QCAMERA_CAMERATRANSLATIONOPTION_IDX       = 40,
+    SBK_QT3DRENDER_QCAMERA_IDX                               = 39,
+    SBK_QT3DRENDER_QCAMERALENS_PROJECTIONTYPE_IDX            = 42,
+    SBK_QT3DRENDER_QCAMERALENS_IDX                           = 41,
+    SBK_QT3DRENDER_QCAMERASELECTOR_IDX                       = 43,
+    SBK_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX              = 45,
     SBK_QFLAGS_QT3DRENDER_QCLEARBUFFERS_BUFFERTYPE_IDX       = 0,
-    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 45,
-    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 46,
-    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 47,
-    SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX               = 48,
-    SBK_QT3DRENDER_QCULLFACE_IDX                             = 49,
-    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 50,
-    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 51,
-    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 52,
-    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 53,
-    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 54,
-    SBK_QT3DRENDER_QDITHERING_IDX                            = 55,
-    SBK_QT3DRENDER_QEFFECT_IDX                               = 56,
-    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 57,
-    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 58,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 59,
-    SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX      = 60,
-    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 61,
-    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 62,
-    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 63,
-    SBK_QT3DRENDER_QGEOMETRY_IDX                             = 64,
-    SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                      = 65,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 66,
-    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 67,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 68,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 69,
-    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 70,
-    SBK_QT3DRENDER_QLAYER_IDX                                = 71,
-    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 72,
-    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 73,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 74,
-    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 75,
-    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 76,
-    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 77,
-    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 78,
-    SBK_QT3DRENDER_QMATERIAL_IDX                             = 79,
-    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 80,
-    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 81,
+    SBK_QT3DRENDER_QCLEARBUFFERS_IDX                         = 44,
+    SBK_QT3DRENDER_QCLIPPLANE_IDX                            = 46,
+    SBK_QT3DRENDER_QCOLORMASK_IDX                            = 47,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_RUNTYPE_IDX               = 49,
+    SBK_QT3DRENDER_QCOMPUTECOMMAND_IDX                       = 48,
+    SBK_QT3DRENDER_QCULLFACE_CULLINGMODE_IDX                 = 51,
+    SBK_QT3DRENDER_QCULLFACE_IDX                             = 50,
+    SBK_QT3DRENDER_QDEPTHTEST_DEPTHFUNCTION_IDX              = 53,
+    SBK_QT3DRENDER_QDEPTHTEST_IDX                            = 52,
+    SBK_QT3DRENDER_QDIRECTIONALLIGHT_IDX                     = 54,
+    SBK_QT3DRENDER_QDISPATCHCOMPUTE_IDX                      = 55,
+    SBK_QT3DRENDER_QDITHERING_IDX                            = 56,
+    SBK_QT3DRENDER_QEFFECT_IDX                               = 57,
+    SBK_QT3DRENDER_QENVIRONMENTLIGHT_IDX                     = 58,
+    SBK_QT3DRENDER_QFILTERKEY_IDX                            = 59,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODE_IDX                       = 60,
+    SBK_QT3DRENDER_QFRAMEGRAPHNODECREATEDCHANGEBASE_IDX      = 61,
+    SBK_QT3DRENDER_QFRONTFACE_WINDINGDIRECTION_IDX           = 63,
+    SBK_QT3DRENDER_QFRONTFACE_IDX                            = 62,
+    SBK_QT3DRENDER_QFRUSTUMCULLING_IDX                       = 64,
+    SBK_QT3DRENDER_QGEOMETRY_IDX                             = 65,
+    SBK_QT3DRENDER_QGEOMETRYFACTORY_IDX                      = 66,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_PRIMITIVETYPE_IDX       = 68,
+    SBK_QT3DRENDER_QGEOMETRYRENDERER_IDX                     = 67,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_API_IDX                = 70,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_OPENGLPROFILE_IDX      = 71,
+    SBK_QT3DRENDER_QGRAPHICSAPIFILTER_IDX                    = 69,
+    SBK_QT3DRENDER_QLAYER_IDX                                = 72,
+    SBK_QT3DRENDER_QLAYERFILTER_FILTERMODE_IDX               = 74,
+    SBK_QT3DRENDER_QLAYERFILTER_IDX                          = 73,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_THRESHOLDTYPE_IDX          = 76,
+    SBK_QT3DRENDER_QLEVELOFDETAIL_IDX                        = 75,
+    SBK_QT3DRENDER_QLEVELOFDETAILBOUNDINGSPHERE_IDX          = 77,
+    SBK_QT3DRENDER_QLEVELOFDETAILSWITCH_IDX                  = 78,
+    SBK_QT3DRENDER_QLINEWIDTH_IDX                            = 79,
+    SBK_QT3DRENDER_QMATERIAL_IDX                             = 80,
+    SBK_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX              = 82,
     SBK_QFLAGS_QT3DRENDER_QMEMORYBARRIER_OPERATION_IDX       = 1,
-    SBK_QT3DRENDER_QMESH_IDX                                 = 82,
-    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 83,
-    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 84,
-    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 85,
-    SBK_QT3DRENDER_QNODRAW_IDX                               = 86,
-    SBK_QT3DRENDER_QNOPICKING_IDX                            = 87,
-    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 88,
-    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 89,
-    SBK_QT3DRENDER_QPARAMETER_IDX                            = 90,
-    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 91,
-    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 92,
-    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 93,
-    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 94,
-    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 95,
-    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 96,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 97,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 99,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 100,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 98,
-    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 101,
-    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 102,
-    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 103,
-    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 104,
-    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 105,
-    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 106,
-    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 107,
-    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 108,
-    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 109,
-    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 110,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 111,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 112,
-    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 113,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 114,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 115,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 116,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 117,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 118,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 119,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 120,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 121,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 122,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 123,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 124,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 125,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 126,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 127,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 129,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 128,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 130,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 131,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 132,
-    SBK_QT3DRENDER_QSETFENCE_IDX                             = 133,
-    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 134,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 135,
-    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 136,
-    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 137,
-    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 138,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 139,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 140,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 141,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 142,
-    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 143,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 144,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 145,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 146,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 147,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 148,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 149,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 150,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 151,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 152,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 153,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 154,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 155,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 156,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 157,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 158,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 159,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 160,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 161,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 162,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 163,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 164,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 165,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 166,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 167,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 168,
-    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 169,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 170,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 171,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 172,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 173,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 174,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 175,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 176,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 177,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 178,
-    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 179,
-    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 180,
-    SBK_Qt3DRender_IDX_COUNT                                 = 181
+    SBK_QT3DRENDER_QMEMORYBARRIER_IDX                        = 81,
+    SBK_QT3DRENDER_QMESH_STATUS_IDX                          = 84,
+    SBK_QT3DRENDER_QMESH_IDX                                 = 83,
+    SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 85,
+    SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 86,
+    SBK_QT3DRENDER_QNODRAW_IDX                               = 87,
+    SBK_QT3DRENDER_QNOPICKING_IDX                            = 88,
+    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 89,
+    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 90,
+    SBK_QT3DRENDER_QPARAMETER_IDX                            = 91,
+    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 93,
+    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 94,
+    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 92,
+    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 95,
+    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 96,
+    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 97,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 100,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 101,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 99,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 98,
+    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 102,
+    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 104,
+    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 103,
+    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 105,
+    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 106,
+    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 107,
+    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 109,
+    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 108,
+    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 111,
+    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 110,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 113,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 114,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 112,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 115,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 116,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 117,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 118,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 120,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 119,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 121,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 122,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 123,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 124,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 126,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 125,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 127,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 130,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 129,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 128,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 131,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 132,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 133,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 135,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 134,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 136,
+    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 138,
+    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 139,
+    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 137,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 142,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 143,
+    SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX                 = 141,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 140,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 144,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 145,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 147,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 146,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 148,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 149,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 150,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 152,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 153,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 151,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 154,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 156,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 157,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 155,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 158,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 159,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 160,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 161,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 162,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 163,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 164,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 165,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 166,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 167,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 168,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 169,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 170,
+    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 171,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 173,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 172,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 174,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 175,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 176,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 177,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 179,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 178,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 180,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 182,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 181,
+    SBK_Qt3DRender_IDX_COUNT                                 = 183
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_Qt3DRenderTypes;
@@ -401,6 +404,7 @@ namespace Shiboken
 // PyType functions, to get the PyObjectType for a type T
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::API >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_API_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::PropertyReaderInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QAbstractFunctor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QAbstractLight::Type >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX]; }
@@ -541,6 +545,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderImage::ImageFormat
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderImage >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERIMAGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram::ShaderType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram::Status >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram::Format >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_FORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgramBuilder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSharedGLTexture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX]); }
